ChannelDeliveryReporter class

Manages the delivery reporting for channel messages.

Collects channels that need delivery acknowledgments and efficiently reports them to the server.

Constructors

ChannelDeliveryReporter({Logger? logger, required MarkChannelsDelivered onMarkChannelsDelivered, Duration throttleDuration = const Duration(seconds: 1)})
Creates a new channel delivery reporter.

Properties

hashCode int
The hash code for this object.
no setterinherited
onMarkChannelsDelivered MarkChannelsDelivered
The callback invoked to send delivery receipts.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cancel() → void
Cancels all pending delivery reports.
cancelDelivery(Iterable<String> channels) Future<void>
Cancels pending delivery reports for channels.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reconcileDelivery(Iterable<Channel> channels) Future<void>
Reconciles delivery reporting for channels with their current state.
submitForDelivery(Iterable<Channel> channels) Future<void>
Submits channels for delivery reporting.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited