skipLastMsgUpdateForSystemMsgs property
If true the last message at date will not be updated when a system message is added.
This is useful for scenarios where you want to track the last time a user message was added to the channel.
Implementation
final bool skipLastMsgUpdateForSystemMsgs;