MessageState class sealed
Represents the various states a message can be in.
- Available extensions
- Annotations
-
- @freezed
Constructors
- MessageState.completed({required CompletedState state})
-
Completed state when the message has been successfully sent, updated, or
deleted.
constfactory
- MessageState.deleted({required MessageDeleteScope scope})
-
Deleting state when the message has been successfully deleted.
factory
- MessageState.deleting({required MessageDeleteScope scope})
-
Deleting state when the message is being deleted.
factory
- MessageState.deletingFailed({required MessageDeleteScope scope})
-
Deleting failed state when the message fails to be deleted.
factory
- MessageState.failed({required FailedState state, Object? reason})
-
Failed state when the message fails to be sent, updated, or deleted.
constfactory
-
MessageState.fromJson(Map<
String, dynamic> json) -
Creates a new instance from a json
factory
- MessageState.initial()
-
Initial state when the message is created.
constfactory
- MessageState.outgoing({required OutgoingState state})
-
Outgoing state when the message is being sent, updated, or deleted.
constfactory
-
MessageState.partialUpdatingFailed({Map<
String, Object?> ? set, List<String> ? unset, required bool skipEnrichUrl}) -
factory
- MessageState.sendingFailed({required bool skipPush, required bool skipEnrichUrl})
-
Sending failed state when the message fails to be sent.
factory
- MessageState.updatingFailed({required bool skipPush, required bool skipEnrichUrl})
-
Updating failed state when the message fails to be updated.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isCompleted → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in completed state.no setter - isDeleted → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in completed deleted state.no setter - isDeletedForMe → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in completed deleted for me state.no setter - isDeleting → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in outgoing deleting state.no setter - isDeletingFailed → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in failed deleting state.no setter - isDeletingForMe → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in outgoing deleting for me state.no setter - isDeletingForMeFailed → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in failed deleting for me state.no setter - isFailed → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in failed state.no setter - isHardDeleted → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in completed hard deleted state.no setter - isHardDeleting → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in outgoing hard deleting state.no setter - isHardDeletingFailed → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in failed hard deleting state.no setter - isInitial → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in initial state.no setter - isOutgoing → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in outgoing state.no setter - isSending → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in outgoing sending state.no setter - isSendingFailed → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in failed sending state.no setter - isSent → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in completed sent state.no setter - isSoftDeleted → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in completed soft deleted state.no setter - isSoftDeleting → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in outgoing soft deleting state.no setter - isSoftDeletingFailed → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in failed soft deleting state.no setter - isUpdated → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in completed updated state.no setter - isUpdating → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in outgoing updating state.no setter - isUpdatingFailed → bool
-
Available on MessageState, provided by the MessageStateX extension
Returns true if the message is in failed updating state.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this MessageState to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- deletedForMe → const MessageState
- Deleted for me state when the message has been successfully deleted only for me.
- deletingForMe → const MessageState
- Deleting for me state when the message is being deleted only for me.
- deletingForMeFailed → const MessageState
- Deleting for me failed state when the message fails to be deleted only
- hardDeleted → const MessageState
- Hard deleted state when the message has been successfully hard deleted.
- hardDeleting → const MessageState
- Hard deleting state when the message is being hard deleted.
- hardDeletingFailed → const MessageState
- Hard deleting failed state when the message fails to be hard deleted.
- sending → const MessageState
- Sending state when the message is being sent.
- sent → const MessageState
- Sent state when the message has been successfully sent.
- softDeleted → const MessageState
- Deleted state when the message has been successfully soft deleted.
- softDeleting → const MessageState
- Deleting state when the message is being soft deleted.
- softDeletingFailed → const MessageState
- Deleting failed state when the message fails to be soft deleted.
- updated → const MessageState
- Updated state when the message has been successfully updated.
- updating → const MessageState
- Updating state when the message is being updated.